## $Id: browser.py 10629 2013-09-20 17:22:10Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""UI components for basic applicants and related components.
"""
import grok
from zope.component import getUtility
from zope.i18n import translate
from waeup.kofa.widgets.datewidget import FriendlyDatetimeDisplayWidget
from zope.formlib.textwidgets import BytesDisplayWidget
from waeup.kofa.applicants.browser import (ApplicantDisplayFormPage,
    ApplicantManageFormPage, ApplicantEditFormPage,
    ApplicantsContainerPage)
from waeup.kofa.applicants.viewlets import (
    PaymentReceiptActionButton, PDFActionButton)
from waeup.kofa.applicants.pdf import PDFApplicationSlip
from kofacustom.nigeria.applicants.interfaces import (
    UG_OMIT_DISPLAY_FIELDS,
    UG_OMIT_PDF_FIELDS,
    UG_OMIT_MANAGE_FIELDS,
    UG_OMIT_EDIT_FIELDS
    )
from waeup.kwarapoly.applicants.interfaces import (
    ICustomUGApplicant, ICustomUGApplicantEdit,
    ND_OMIT_DISPLAY_FIELDS,
    ND_OMIT_PDF_FIELDS,
    ND_OMIT_MANAGE_FIELDS,
    ND_OMIT_EDIT_FIELDS
    )

UG_OMIT_EDIT_FIELDS = [
    value for value in UG_OMIT_EDIT_FIELDS
        if not value in ('jamb_subjects', 'jamb_score')]

PREJAMBITES_OMIT_EDIT_FIELDS = UG_OMIT_EDIT_FIELDS + [
    'firstname',
    'middlename',
    'lastname',
    'sex',
    'jamb_score'
    ]

class CustomApplicantsContainerPage(ApplicantsContainerPage):
    """The standard view for regular applicant containers.
    """

    @property
    def form_fields(self):
        form_fields = super(CustomApplicantsContainerPage, self).form_fields
        if self.request.principal.id == 'zope.anybody':
            return form_fields.omit('application_fee')
        return form_fields

class CustomApplicantDisplayFormPage(ApplicantDisplayFormPage):
    """A display view for applicant data.
    """

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomUGApplicant)
        if self.context.is_nd:
            for field in ND_OMIT_DISPLAY_FIELDS:
                form_fields = form_fields.omit(field)
        else:
            form_fields = grok.AutoFields(ICustomUGApplicant)
            for field in UG_OMIT_DISPLAY_FIELDS:
                form_fields = form_fields.omit(field)
        form_fields['notice'].custom_widget = BytesDisplayWidget
        form_fields['jamb_subjects'].custom_widget = BytesDisplayWidget
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        if not getattr(self.context, 'screening_score'):
            form_fields = form_fields.omit('screening_score')
        if not getattr(self.context, 'screening_venue'):
            form_fields = form_fields.omit('screening_venue')
        if not getattr(self.context, 'screening_date'):
            form_fields = form_fields.omit('screening_date')
        return form_fields

class CustomPDFApplicationSlip(PDFApplicationSlip):

    def _reduced_slip(self):
        return getattr(self.context, 'result_uploaded', False)

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomUGApplicant)
        if self.context.is_nd:
            for field in ND_OMIT_PDF_FIELDS:
                form_fields = form_fields.omit(field)
        else:
            form_fields = grok.AutoFields(ICustomUGApplicant)
            for field in UG_OMIT_PDF_FIELDS:
                form_fields = form_fields.omit(field)
        if not getattr(self.context, 'student_id'):
            form_fields = form_fields.omit('student_id')
        if not getattr(self.context, 'screening_score'):
            form_fields = form_fields.omit('screening_score')
        if not getattr(self.context, 'screening_venue'):
            form_fields = form_fields.omit('screening_venue')
        if not getattr(self.context, 'screening_date'):
            form_fields = form_fields.omit('screening_date')
        return form_fields

class CustomApplicantManageFormPage(ApplicantManageFormPage):
    """A full edit view for applicant data.
    """
    
    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomUGApplicant)
        if self.context.is_nd:
            for field in ND_OMIT_MANAGE_FIELDS:
                form_fields = form_fields.omit(field)
        else:
            for field in UG_OMIT_MANAGE_FIELDS:
                form_fields = form_fields.omit(field)
        form_fields['student_id'].for_display = True
        form_fields['applicant_id'].for_display = True
        return form_fields

class CustomApplicantEditFormPage(ApplicantEditFormPage):
    """An applicant-centered edit view for applicant data.
    """

    @property
    def form_fields(self):
        form_fields = grok.AutoFields(ICustomUGApplicantEdit)
        if self.context.is_nd:
            for field in ND_OMIT_EDIT_FIELDS:
                form_fields = form_fields.omit(field)
        elif self.target is not None and self.target.startswith('prejambites'):
            for field in PREJAMBITES_OMIT_EDIT_FIELDS:
                form_fields = form_fields.omit(field)
        else:
            for field in UG_OMIT_EDIT_FIELDS:
                form_fields = form_fields.omit(field)
        form_fields['applicant_id'].for_display = True
        form_fields['reg_number'].for_display = True
        return form_fields